@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 """
-@Author: CaiYouBin
-@Date: 2020-05-26 15:26:32
-@LastEditTime: 2020-12-16 17:26:23
-@LastEditors: HuangJingCan
-@Description: 客户端活动处理
+:Author: CaiYouBin
+:Date: 2020-05-26 15:26:32
+:LastEditTime: 2020-12-29 10:37:08
+:LastEditors: HuangJingCan
+:description: 客户端活动处理
 """
 from seven_cloudapp.handlers.seven_base import *
 
@@ -16,14 +16,15 @@ from seven_cloudapp.models.db_models.app.app_info_model import *
 
 class ActInfoHandler(SevenBaseHandler):
     """
-    @description: 获取活动信息
+    :description: 获取活动信息
     """
+    @filter_check_params("act_id")
     def get_async(self):
         """
-        @description: 获取活动信息
-        @param act_id：活动id
-        @return: 字典
-        @last_editors: HuangJingCan
+        :description: 获取活动信息
+        :param act_id：活动id
+        :return: 字典
+        :last_editors: HuangJingCan
         """
         act_id = int(self.get_param("act_id", 0))
 
@@ -35,12 +36,12 @@ class ActInfoHandler(SevenBaseHandler):
             return self.reponse_json_error("NoApp", "对不起，找不到该小程序")
 
         act_info_model = ActInfoModel()
-        act_info = act_info_model.get_entity("id=%s", params=act_id)
+        act_info = act_info_model.get_dict_by_id(act_id)
         if not act_info:
             return self.reponse_json_error("NoAct", "对不起，找不到该活动")
 
-        act_info.seller_id = app_info.seller_id
-        act_info.store_id = app_info.store_id
-        act_info.store_name = app_info.store_name
+        act_info["seller_id"] = app_info.seller_id
+        act_info["store_id"] = app_info.store_id
+        act_info["store_name"] = app_info.store_name
 
         self.reponse_json_success(act_info)
\ No newline at end of file
