@@ -1,28 +1,29 @@
 # -*- coding: utf-8 -*-
 """
-@Author: HuangJingCan
-@Date: 2020-05-24 17:26:33
-@LastEditTime: 2020-12-24 16:06:48
-@LastEditors: HuangJingCan
-@Description: 基础信息相关
+:Author: HuangJingCan
+:Date: 2020-05-24 17:26:33
+:LastEditTime: 2021-01-18 16:51:22
+:LastEditors: HuangJingCan
+:description: 基础信息相关
 """
 from seven_cloudapp.handlers.top_base import *
 
 from seven_cloudapp.models.db_models.base.base_info_model import *
 from seven_cloudapp.models.db_models.app.app_info_model import *
 from seven_cloudapp.models.db_models.saas.saas_custom_model import *
+from seven_cloudapp.models.db_models.product.product_price_model import *
 
 
 class LeftNavigationHandler(TopBaseHandler):
     """
-    @description: 左侧导航栏
+    :description: 左侧导航栏
     """
     def get_async(self):
         """
-        @description: 左侧导航栏
-        @param {*}
-        @return 字典
-        @last_editors: HuangJingCan
+        :description: 左侧导航栏
+        :param {*}
+        :return 字典
+        :last_editors: HuangJingCan
         """
         user_nick = self.get_taobao_param().user_nick
         if not user_nick:
@@ -42,11 +43,12 @@ class LeftNavigationHandler(TopBaseHandler):
         # 左上角信息
         info = {}
         info["company"] = "天志互联"
-        info["miniappName"] = config.get_value("project_name")
-        info["logo"] = config.get_value("project_logo")
+        info["miniappName"] = base_info.product_name
+        info["logo"] = base_info.product_icon
 
         # 左边底部菜单
         helper_info = {}
+        # 钉钉号
         helper_info["customer_service"] = "http://amos.alicdn.com/getcid.aw?v=2&uid=%E5%A4%A9%E5%BF%97%E4%BA%92%E8%81%94&site=cntaobao&s=1&groupid=0&charset=utf-8"
         helper_info["video_url"] = base_info.video_url
         helper_info["study_url"] = base_info.study_url
@@ -71,21 +73,29 @@ class LeftNavigationHandler(TopBaseHandler):
         data["helper_info"] = helper_info
         data["renew_info"] = renew_info
         if base_info.product_price:
-            data["renew_prices"] = ast.literal_eval(base_info.product_price)
+            data["renew_prices"] = self.json_loads(base_info.product_price)
+
+        product_price = ProductPriceModel().get_entity("is_release=1")
+        if product_price and product_price.content:
+            begin_time = TimeHelper.format_time_to_datetime(product_price.begin_time)
+            end_time = TimeHelper.format_time_to_datetime(product_price.end_time)
+            this_time = TimeHelper.get_now_datetime()
+            if this_time >= begin_time and this_time <= end_time:
+                data["renew_prices"] = self.json_loads(product_price.content)
 
         self.reponse_json_success(data)
 
 
 class RightExplainHandler(SevenBaseHandler):
     """
-    @description: 右侧各种教程和说明导航
+    :description: 右侧各种教程和说明导航
     """
     def get_async(self):
         """
-        @description: 右侧各种教程和说明导航
-        @param {*}
-        @return dict
-        @last_editors: HuangJingCan
+        :description: 右侧各种教程和说明导航
+        :param {*}
+        :return dict
+        :last_editors: HuangJingCan
         """
         base_info = BaseInfoModel().get_entity()
         if not base_info:
@@ -101,14 +111,14 @@ class RightExplainHandler(SevenBaseHandler):
 
 class FriendLinkHandler(SevenBaseHandler):
     """
-    @description: 获取友情链接
+    :description: 获取友情链接
     """
     def get_async(self):
         """
-        @description: 获取友情链接
-        @param {*}
-        @return list
-        @last_editors: HuangJingCan
+        :description: 获取友情链接
+        :param {*}
+        :return list
+        :last_editors: HuangJingCan
         """
         base_info = BaseInfoModel().get_entity()
         if not base_info:
@@ -124,15 +134,15 @@ class FriendLinkHandler(SevenBaseHandler):
 
 class UpdateInfoHandler(SevenBaseHandler):
     """
-    @description: 获取更新信息
+    :description: 获取更新信息
     """
     @filter_check_params("app_id")
     def get_async(self):
         """
-        @description: 获取更新信息
-        @param app_id：app_id
-        @return dict
-        @last_editors: HuangJingCan
+        :description: 获取更新信息
+        :param app_id：app_id
+        :return dict
+        :last_editors: HuangJingCan
         """
         app_id = self.get_param("app_id")
 
@@ -148,25 +158,29 @@ class UpdateInfoHandler(SevenBaseHandler):
         data["client_ver"] = base_info.client_ver
         data["server_ver"] = base_info.server_ver
         data["client_now_ver"] = app_info.template_ver
+        data["is_force_update"] = base_info.is_force_update
         data["update_function"] = []
         if base_info.update_function:
-            data["update_function"] = base_info.update_function
+            data["update_function"] = self.json_loads(base_info.update_function)
+        data["update_function_b"] = []
+        if base_info.update_function_b:
+            data["update_function_b"] = self.json_loads(base_info.update_function_b)
 
         self.reponse_json_success(data)
 
 
 class OnlineLiveUrlHandler(SevenBaseHandler):
     """
-    @description: 小程序链接
+    :description: 小程序链接
     """
     @filter_check_params("app_id,act_id")
     def get_async(self):
         """
-        @description: 小程序链接
-        @param app_id：app_id
-        @param act_id：活动id
-        @return dict
-        @last_editors: HuangJingCan
+        :description: 小程序链接
+        :param app_id：app_id
+        :param act_id：活动id
+        :return dict
+        :last_editors: HuangJingCan
         """
         app_id = self.get_param("app_id")
         act_id = int(self.get_param("act_id", 0))
@@ -188,14 +202,14 @@ class OnlineLiveUrlHandler(SevenBaseHandler):
 
 class DecorationPosterHandler(SevenBaseHandler):
     """
-    @description: 装修海报
+    :description: 装修海报
     """
     def get_async(self):
         """
-        @description: 装修海报
-        @param {*}
-        @return dict
-        @last_editors: HuangJingCan
+        :description: 装修海报
+        :param {*}
+        :return dict
+        :last_editors: HuangJingCan
         """
         base_info = BaseInfoModel().get_entity()
         if not base_info:
@@ -211,14 +225,14 @@ class DecorationPosterHandler(SevenBaseHandler):
 
 class SaasCustomHandler(SevenBaseHandler):
     """
-    @description: saas定制化信息获取
+    :description: saas定制化信息获取
     """
     def get_async(self):
         """
-        @description: saas定制化信息获取
-        @param {*}
-        @return int
-        @last_editors: HuangJingCan
+        :description: saas定制化信息获取
+        :param {*}
+        :return int
+        :last_editors: HuangJingCan
         """
         user_nick = self.get_taobao_param().user_nick
         if not user_nick:
@@ -232,4 +246,27 @@ class SaasCustomHandler(SevenBaseHandler):
         if saas_custom:
             cloud_app_id = saas_custom.cloud_app_id
 
-        self.reponse_json_success(cloud_app_id)
\ No newline at end of file
+        self.reponse_json_success(cloud_app_id)
+
+
+class OperateLoginHandler(SevenBaseHandler):
+    """
+    :description: 根据店铺名称获取app_id
+    """
+    @filter_check_params("store_name")
+    def get_async(self):
+        """
+        :description: 根据店铺名称获取app_id
+        :param store_name:店铺名称
+        :return str
+        :last_editors: HuangJingCan
+        """
+        store_name = self.get_param("store_name")
+
+        app_info = AppInfoModel().get_dict("store_name=%s", params=store_name)
+
+        app_id = ""
+        if app_info:
+            app_id = app_info['app_id']
+
+        self.reponse_json_success(app_id)
\ No newline at end of file
