@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 """
-@Author: HuangJingCan
-@Date: 2020-06-02 11:08:39
-@LastEditTime: 2020-12-18 14:10:04
-@LastEditors: HuangJingCan
-@Description: 订单相关
+:Author: HuangJingCan
+:Date: 2020-06-02 11:08:39
+:LastEditTime: 2021-01-28 10:26:31
+:LastEditors: HuangJingCan
+:description: 订单相关
 """
 from seven_cloudapp.handlers.seven_base import *
 
@@ -20,21 +20,21 @@ from seven_cloudapp.libs.customize.oss2help import *
 
 class PayOrderListHandler(SevenBaseHandler):
     """
-    @description: 用户购买订单
+    :description: 用户购买订单
     """
     @filter_check_params("act_id")
     def get_async(self):
         """
-        @description: 用户购买订单
-        @param page_index：页索引
-        @param page_size：页大小
-        @param act_id：活动id
-        @param user_open_id：用户唯一标识
-        @param pay_date_start：订单支付时间开始
-        @param pay_date_end：订单支付时间结束
-        @param nick_name：用户昵称
-        @return: 列表
-        @last_editors: HuangJingCan
+        :description: 用户购买订单
+        :param page_index：页索引
+        :param page_size：页大小
+        :param act_id：活动id
+        :param user_open_id：用户唯一标识
+        :param pay_date_start：订单支付时间开始
+        :param pay_date_end：订单支付时间结束
+        :param nick_name：用户昵称
+        :return: 列表
+        :last_editors: HuangJingCan
         """
         page_index = int(self.get_param("page_index", 0))
         page_size = int(self.get_param("page_size", 10))
@@ -69,25 +69,25 @@ class PayOrderListHandler(SevenBaseHandler):
 
 class PrizeOrderListHandler(SevenBaseHandler):
     """
-    @description: 用户奖品订单
+    :description: 用户奖品订单
     """
     @filter_check_params("act_id")
     def get_async(self):
         """
-        @description: 用户奖品订单
-        @param page_index：页索引
-        @param page_size：页大小
-        @param act_id：活动id
-        @param order_no：订单号
-        @param nick_name：用户昵称
-        @param real_name：用户名字
-        @param telephone：联系电话
-        @param adress：收货地址
-        @param order_status：订单状态
-        @param create_date_start：订单创建时间开始
-        @param create_date_end：订单创建时间结束
-        @return: 列表
-        @last_editors: HuangJingCan
+        :description: 用户奖品订单
+        :param page_index：页索引
+        :param page_size：页大小
+        :param act_id：活动id
+        :param order_no：订单号
+        :param nick_name：用户昵称
+        :param real_name：用户名字
+        :param telephone：联系电话
+        :param adress：收货地址
+        :param order_status：订单状态
+        :param create_date_start：订单创建时间开始
+        :param create_date_end：订单创建时间结束
+        :return: 列表
+        :last_editors: HuangJingCan
         """
         page_index = int(self.get_param("page_index", 0))
         page_size = int(self.get_param("page_size", 10))
@@ -97,7 +97,7 @@ class PrizeOrderListHandler(SevenBaseHandler):
         real_name = self.get_param("real_name")
         telephone = self.get_param("telephone")
         adress = self.get_param("adress")
-        order_status = self.get_param("order_status")
+        order_status = int(self.get_param("order_status", -1))
         create_date_start = self.get_param("create_date_start")
         create_date_end = self.get_param("create_date_end")
 
@@ -112,7 +112,7 @@ class PrizeOrderListHandler(SevenBaseHandler):
             params.append(user_nick)
         if real_name:
             condition += " AND real_name=%s"
-            params.append(user_nick)
+            params.append(real_name)
         if telephone:
             condition += " AND telephone=%s"
             params.append(telephone)
@@ -120,7 +120,7 @@ class PrizeOrderListHandler(SevenBaseHandler):
             adress = f"%{adress}%"
             condition += " AND adress LIKE %s"
             params.append(adress)
-        if order_status or order_status == "-1":
+        if order_status >= 0:
             condition += " AND order_status=%s"
             params.append(order_status)
         if create_date_start:
@@ -139,25 +139,25 @@ class PrizeOrderListHandler(SevenBaseHandler):
 
 class PrizeRosterListHandler(SevenBaseHandler):
     """
-    @description: 用户奖品列表
+    :description: 用户奖品列表
     """
     @filter_check_params("act_id")
     def get_async(self):
         """
-        @description: 用户奖品列表
-        @param page_index：页索引
-        @param page_size：页大小
-        @param act_id：活动id
-        @param prize_order_id：奖品订单id
-        @param prize_type：奖品类型（1实物2店铺商品3优惠券4参与奖5谢谢参与）
-        @param nick_name：用户昵称
-        @param is_submit：是否提交
-        @param order_status：订单状态
-        @param create_date_start：订单创建时间开始
-        @param create_date_end：订单创建时间结束
-        @param user_open_id：用户唯一标识
-        @return: list
-        @last_editors: HuangJingCan
+        :description: 用户奖品列表
+        :param page_index：页索引
+        :param page_size：页大小
+        :param act_id：活动id
+        :param prize_order_id：奖品订单id
+        :param prize_type：奖品类型（1实物2店铺商品3优惠券4参与奖5谢谢参与）
+        :param nick_name：用户昵称
+        :param is_submit：是否提交
+        :param order_status：订单状态
+        :param create_date_start：订单创建时间开始
+        :param create_date_end：订单创建时间结束
+        :param user_open_id：用户唯一标识
+        :return: list
+        :last_editors: HuangJingCan
         """
         page_index = int(self.get_param("page_index", 0))
         page_size = int(self.get_param("page_size", 10))
@@ -166,7 +166,7 @@ class PrizeRosterListHandler(SevenBaseHandler):
         user_nick = self.get_param("nick_name")
         is_submit = self.get_param("is_submit")
         prize_type = int(self.get_param("prize_type", 0))
-        order_status = int(self.get_param("order_status", 0))
+        order_status = int(self.get_param("order_status", -1))
         create_date_start = self.get_param("create_date_start")
         create_date_end = self.get_param("create_date_end")
         user_open_id = self.get_param("user_open_id")
@@ -188,7 +188,7 @@ class PrizeRosterListHandler(SevenBaseHandler):
                 condition += " AND prize_order_id=0"
             else:
                 condition += " AND prize_order_id>0"
-        if order_status:
+        if order_status >= 0:
             condition += " AND order_status=%s"
             params.append(order_status)
         if create_date_start:
@@ -210,18 +210,18 @@ class PrizeRosterListHandler(SevenBaseHandler):
 
 class PrizeOrderStatusHandler(SevenBaseHandler):
     """
-    @description: 更新用户奖品订单状态
+    :description: 更新用户奖品订单状态
     """
     @filter_check_params("prize_order_id,order_status")
     def post_async(self):
         """
-        @description: 更新用户奖品订单状态
-        @param prize_order_id：奖品订单id
-        @param order_status：订单状态
-        @param express_company：快递公司
-        @param express_no：快递单号
-        @return: reponse_json_success
-        @last_editors: HuangJingCan
+        :description: 更新用户奖品订单状态
+        :param prize_order_id：奖品订单id
+        :param order_status：订单状态
+        :param express_company：快递公司
+        :param express_no：快递单号
+        :return: reponse_json_success
+        :last_editors: HuangJingCan
         """
         prize_order_id = int(self.get_param("prize_order_id", 0))
         order_status = int(self.get_param("order_status", 0))
@@ -247,16 +247,16 @@ class PrizeOrderStatusHandler(SevenBaseHandler):
 
 class PrizeOrderRemarksHandler(SevenBaseHandler):
     """
-    @description: 更新用户奖品订单备注
+    :description: 更新用户奖品订单备注
     """
     @filter_check_params("prize_order_id,remarks")
     def post_async(self):
         """
-        @description: 更新用户奖品订单备注
-        @param prize_order_id：奖品订单id
-        @param remarks：备注
-        @return: 
-        @last_editors: HuangJingCan
+        :description: 更新用户奖品订单备注
+        :param prize_order_id：奖品订单id
+        :param remarks：备注
+        :return: 
+        :last_editors: HuangJingCan
         """
         prize_order_id = int(self.get_param("prize_order_id", 0))
         remarks = self.get_param("remarks")
@@ -268,25 +268,25 @@ class PrizeOrderRemarksHandler(SevenBaseHandler):
 
 class PrizeOrderExportHandler(SevenBaseHandler):
     """
-    @description: 导出订单
+    :description: 导出订单
     """
     @filter_check_params("act_id")
     def get_async(self):
         """
-        @description: 导出订单
-        @param page_index：页索引
-        @param page_size：页大小
-        @param act_id：活动id
-        @param order_no：订单号
-        @param order_status：订单状态
-        @param nick_name：用户昵称
-        @param is_machine：是否机台
-        @return str
-        @last_editors: HuangJingCan
+        :description: 导出订单
+        :param page_index：页索引
+        :param page_size：页大小
+        :param act_id：活动id
+        :param order_no：订单号
+        :param order_status：订单状态
+        :param nick_name：用户昵称
+        :param is_machine：是否机台
+        :return str
+        :last_editors: HuangJingCan
         """
         page_index = int(self.get_param("page_index", 0))
         page_size = int(self.get_param("page_size", 500))
-        act_id = self.get_param("act_id")
+        act_id = int(self.get_param("act_id", 0))
         order_no = self.get_param("order_no")
         order_status = int(self.get_param("order_status", -1))
         user_nick = self.get_param("nick_name")
@@ -363,20 +363,19 @@ class PrizeOrderExportHandler(SevenBaseHandler):
 
 class PrizeOrderImportHandler(SevenBaseHandler):
     """
-    @description: 订单导入
+    :description: 订单导入
     """
     @filter_check_params("content,act_id")
     def post_async(self):
         """
-        @description: 
-        @param content：base64加密后的excel内容
-        @param act_id：活动id
-        @return 
-        @last_editors: HuangJingCan
+        :description: 
+        :param content：base64加密后的excel内容
+        :param act_id：活动id
+        :return 
+        :last_editors: HuangJingCan
         """
         content = self.get_param("content")
         act_id = int(self.get_param("act_id", 0))
-        prize_order_model = PrizeOrderModel()
 
         if act_id <= 0:
             return self.reponse_json_error("NoAct", "对不起，无效活动，无法导入订单")
@@ -419,9 +418,10 @@ class PrizeOrderImportHandler(SevenBaseHandler):
 
             if order_no and express_no and express_company:
                 update_sql = "express_no=%s, express_company=%s, order_status=1, deliver_date=%s"
-                params = [express_no, express_company, self.get_now_datetime(), order_no, act_id]
+                params = [express_no, express_company, self.get_now_datetime(), order_no]
                 # print(order_no + express_company)
-                prize_order_model.update_table(update_sql, "order_no=%s and act_id=%s ", params=params)
+                PrizeOrderModel().update_table(update_sql, "order_no=%s", params)
+                PrizeRosterModel().update_table("order_status=1", "prize_order_no=%s", [order_no])
 
         os.remove(path)
 
@@ -431,21 +431,21 @@ class PrizeOrderImportHandler(SevenBaseHandler):
 
 class PrizeRosterExportHandler(SevenBaseHandler):
     """
-    @description: 批量奖品列表导出
+    :description: 批量奖品列表导出
     """
     @filter_check_params("act_id")
     def get_async(self):
         """
-        @description: 批量奖品列表导出
-        @param page_index：页索引
-        @param page_size：页大小
-        @param act_id：活动id
-        @param order_no：订单号
-        @param order_status：订单状态
-        @param nick_name：用户昵称
-        @param is_machine：是否机台
-        @return str
-        @last_editors: HuangJingCan
+        :description: 批量奖品列表导出
+        :param page_index：页索引
+        :param page_size：页大小
+        :param act_id：活动id
+        :param order_no：订单号
+        :param order_status：订单状态
+        :param nick_name：用户昵称
+        :param is_machine：是否机台
+        :return str
+        :last_editors: HuangJingCan
         """
         page_index = int(self.get_param("page_index", 0))
         page_size = int(self.get_param("page_size", 500))
