@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 """
-@Author: CaiYouBin
-@Date: 2020-06-12 11:04:12
-@LastEditTime: 2020-12-24 18:00:34
-@LastEditors: HuangJingCan
-@Description: 
+:Author: CaiYouBin
+:Date: 2020-06-12 11:04:12
+:LastEditTime: 2020-12-28 14:09:23
+:LastEditors: HuangJingCan
+:description: 
 """
 import random
 from seven_cloudapp.handlers.seven_base import *
@@ -17,14 +17,14 @@ from seven_framework.redis import *
 
 class SendSmsHandler(SevenBaseHandler):
     """
-    @description: 发送短信
+    :description: 发送短信
     """
     def get_async(self):
         """
-        @description: 发送短信
-        @param thelephone：电话号码
-        @return 
-        @last_editors: HuangJingCan
+        :description: 发送短信
+        :param thelephone：电话号码
+        :return 
+        :last_editors: HuangJingCan
         """
         open_id = self.get_taobao_param().open_id
         thelephone = self.get_param("thelephone")
@@ -47,7 +47,7 @@ class SendSmsHandler(SevenBaseHandler):
 
         response = client.do_action(request)
 
-        result = dict(self.json_loads(response))
+        result = dict(json.loads(response))
         result["result_code"] = result_code
         #记录验证码
         self.redis_init().set("user_" + open_id + "_bind_phone_code", result_code, ex=300)
