@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 """
-@Author: HuangJingCan
-@Date: 2020-05-12 20:11:48
-@LastEditTime: 2020-12-24 16:01:08
-@LastEditors: HuangJingCan
-@Description: SevenBaseHandler
+:Author: HuangJingCan
+:Date: 2020-05-12 20:11:48
+:LastEditTime: 2021-01-18 12:59:06
+:LastEditors: HuangJingCan
+:description: SevenBaseHandler
 """
 import ast
 import random
@@ -14,14 +14,12 @@ from seven_framework.redis import *
 from seven_cloudapp.models.taobao_model import *
 from seven_cloudapp.models.db_models.operation.operation_log_model import *
 from seven_cloudapp.models.db_models.user.user_info_model import *
+from seven_cloudapp.models.db_models.app.app_info_model import *
 
 
 class SevenBaseHandler(BaseApiHandler):
     """
-    @description: 
-    @param {type} 
-    @return: 
-    @last_editors: HuangJingCan
+    :description: SevenBaseHandler
     """
     def options_async(self):
         self.reponse_json_success()
@@ -31,46 +29,48 @@ class SevenBaseHandler(BaseApiHandler):
 
     def json_dumps(self, rep_dic):
         """
-        @description: 将字典转化为字符串
-        @param rep_dic：字典对象
-        @return: str
-        @last_editors: HuangJingCan
+        :description: 将字典转化为字符串
+        :param rep_dic：字典对象
+        :return: str
+        :last_editors: HuangJingCan
         """
         if isinstance(rep_dic, str):
-            rep_dic = eval(rep_dic)
+            rep_dic = ast.literal_eval(rep_dic)
         if hasattr(rep_dic, '__dict__'):
             rep_dic = rep_dic.__dict__
         return json.dumps(rep_dic, ensure_ascii=False, cls=JsonEncoder)
 
     def json_loads(self, rep_str):
         """
-        @description: 将字符串转化为字典
-        @param rep_str：str
-        @return: dict
-        @last_editors: HuangJingCan
+        :description: 将字符串转化为字典
+        :param rep_str：str
+        :return: dict
+        :last_editors: HuangJingCan
         """
-        if isinstance(rep_str, str):
-            rep_str = eval(rep_str)
-        return json.loads(self.json_dumps(rep_str))
+        try:
+            return json.loads(rep_str)
+        except Exception as ex:
+            if "Expecting property name enclosed" in str(ex):
+                return json.loads(self.json_dumps(rep_str))
 
     def reponse_custom(self, rep_dic):
         """
-        @description: 输出公共json模型
-        @param rep_dic: 字典类型数据
-        @return: 将dumps后的数据字符串返回给客户端
-        @last_editors: HuangJingCan
+        :description: 输出公共json模型
+        :param rep_dic: 字典类型数据
+        :return: 将dumps后的数据字符串返回给客户端
+        :last_editors: HuangJingCan
         """
         self.http_reponse(self.json_dumps(rep_dic))
 
     def reponse_common(self, success=True, data=None, error_code="", error_message=""):
         """
-        @description: 输出公共json模型
-        @param success: 布尔值，表示本次调用是否成功
-        @param data: 类型不限，调用成功（success为true）时，服务端返回的数据
-        @param errorCode: 字符串，调用失败（success为false）时，服务端返回的错误码
-        @param errorMessage: 字符串，调用失败（success为false）时，服务端返回的错误信息
-        @return: 将dumps后的数据字符串返回给客户端
-        @last_editors: HuangJingCan
+        :description: 输出公共json模型
+        :param success: 布尔值，表示本次调用是否成功
+        :param data: 类型不限，调用成功（success为true）时，服务端返回的数据
+        :param errorCode: 字符串，调用失败（success为false）时，服务端返回的错误码
+        :param errorMessage: 字符串，调用失败（success为false）时，服务端返回的错误信息
+        :return: 将dumps后的数据字符串返回给客户端
+        :last_editors: HuangJingCan
         """
         if hasattr(data, '__dict__'):
             data = data.__dict__
@@ -88,39 +88,59 @@ class SevenBaseHandler(BaseApiHandler):
 
     def reponse_json_success(self, data=None):
         """
-        @description: 通用成功返回json结构
-        @param data: 返回结果对象，即为数组，字典
-        @return: 将dumps后的数据字符串返回给客户端
-        @last_editors: HuangJingCan
+        :description: 通用成功返回json结构
+        :param data: 返回结果对象，即为数组，字典
+        :return: 将dumps后的数据字符串返回给客户端
+        :last_editors: HuangJingCan
         """
         self.reponse_common(data=data)
 
-    def reponse_json_error(self, error_code="", error_message="", data=None):
+    def reponse_json_error(self, error_code="", error_message="", data=None, log_type=0):
         """
-        @description: 通用错误返回json结构
-        @param errorCode: 字符串，调用失败（success为false）时，服务端返回的错误码
-        @param errorMessage: 字符串，调用失败（success为false）时，服务端返回的错误信息
-        @param data: 返回结果对象，即为数组，字典
-        @return: 将dumps后的数据字符串返回给客户端
-        @last_editors: HuangJingCan
+        :description: 通用错误返回json结构
+        :param errorCode: 字符串，调用失败（success为false）时，服务端返回的错误码
+        :param errorMessage: 字符串，调用失败（success为false）时，服务端返回的错误信息
+        :param data: 返回结果对象，即为数组，字典
+        :param log_type: 日志记录类型（0-不记录，1-info，2-error）
+        :return: 将dumps后的数据字符串返回给客户端
+        :last_editors: HuangJingCan
         """
-        self.logger_error.error(f"{error_code}\n{error_message}\n{data}\n{self.request}")
+        if log_type == 1:
+            self.logger_info.info(f"{error_code}\n{error_message}\n{data}\n{self.request}")
+        elif log_type == 2:
+            self.logger_error.error(f"{error_code}\n{error_message}\n{data}\n{self.request}")
         self.reponse_common(False, data, error_code, error_message)
 
     def reponse_json_error_params(self):
         """
-        @description: 通用参数错误返回json结构
-        @param desc: 返错误描述
-        @return: 将dumps后的数据字符串返回给客户端
-        @last_editors: ChenXiaolei
+        :description: 通用参数错误返回json结构
+        :param desc: 返错误描述
+        :return: 将dumps后的数据字符串返回给客户端
+        :last_editors: ChenXiaolei
         """
         self.reponse_common(False, None, "params error", "参数错误")
 
+    def return_dict_error(self, error_code="", error_message=""):
+        """
+        :description: 返回error信息字典模型
+        :param errorCode: 字符串，服务端返回的错误码
+        :param errorMessage: 字符串，服务端返回的错误信息
+        :return: dict
+        :last_editors: HuangJingCan
+        """
+        rep_dic = {}
+        rep_dic['error_code'] = error_code
+        rep_dic['error_message'] = error_message
+
+        self.logger_error.error(f"{error_code}\n{error_message}\n{self.request}")
+
+        return rep_dic
+
     def redis_init(self, db=None):
         """
-        @description: redis初始化
-        @return: redis_cli
-        @last_editors: HuangJingCan
+        :description: redis初始化
+        :return: redis_cli
+        :last_editors: HuangJingCan
         """
         host = config.get_value("redis")["host"]
         port = config.get_value("redis")["port"]
@@ -132,10 +152,9 @@ class SevenBaseHandler(BaseApiHandler):
 
     def get_taobao_param(self):
         """
-        @description: 获取淘宝上下文参数
-        @param {type} 
-        @return: 
-        @last_editors: HuangJingCan
+        :description: 获取淘宝上下文参数
+        :return: TaoBaoParam
+        :last_editors: HuangJingCan
         """
         app_key = self.get_param("app_key")
         user_nick = self.get_param("user_nick")
@@ -177,12 +196,30 @@ class SevenBaseHandler(BaseApiHandler):
 
         return info
 
+    def get_app_id(self):
+        """
+        :description: 获取app_id
+        :param self
+        :return str
+        :last_editors: HuangJingCan
+        """
+        app_id = self.get_param("app_id")
+        if app_id == "":
+            user_nick = self.get_taobao_param().user_nick
+            if user_nick:
+                store_user_nick = user_nick.split(':')[0]
+                if store_user_nick:
+                    dict_app_id = AppInfoModel().get_dict("store_user_nick=%s", field="app_id", params=store_user_nick)
+                    if dict_app_id:
+                        app_id = dict_app_id["app_id"]
+        return app_id
+
     def create_order_id(self, ran=5):
         """
-        @description: 生成订单号
-        @param ran：随机数位数，默认5位随机数（0-5）
-        @return: 25位的订单号
-        @last_editors: HuangJingCan
+        :description: 生成订单号
+        :param ran：随机数位数，默认5位随机数（0-5）
+        :return: 25位的订单号
+        :last_editors: HuangJingCan
         """
         ran_num = ""
         if ran == 1:
@@ -202,22 +239,23 @@ class SevenBaseHandler(BaseApiHandler):
 
     def get_now_datetime(self):
         """
-        @description: 获取当前时间加8小时
-        @return: str
-        @last_editors: HuangJingCan
+        :description: 获取当前时间
+        :return: str
+        :last_editors: HuangJingCan
         """
-        return TimeHelper.add_hours_by_format_time(hour=8)
+        add_hours = config.get_value("add_hours", 0)
+        return TimeHelper.add_hours_by_format_time(hour=add_hours)
 
     def create_operation_log(self, operation_type=1, model_name="", handler_name="", detail=None, update_detail=None):
         """
-        @description: 创建操作日志
-        @param operation_type：操作类型：1-add，2-update，3-delete
-        @param model_name：模块或表名称
-        @param handler_name：handler名称
-        @param detail：当前信息
-        @param update_detail：更新之后的信息
-        @return: 
-        @last_editors: HuangJingCan
+        :description: 创建操作日志
+        :param operation_type：操作类型：1-add，2-update，3-delete
+        :param model_name：模块或表名称
+        :param handler_name：handler名称
+        :param detail：当前信息
+        :param update_detail：更新之后的信息
+        :return: 
+        :last_editors: HuangJingCan
         """
         operation_log = OperationLog()
         operation_log_model = OperationLogModel()
@@ -250,9 +288,9 @@ class SevenBaseHandler(BaseApiHandler):
 
     def get_is_test(self):
         """
-        @description: 判断是否本地测试
-        @return: bool
-        @last_editors: HuangJianYi
+        :description: 判断是否本地测试
+        :return: bool
+        :last_editors: HuangJianYi
         """
         if self.get_taobao_param().env != "online":
             return True
@@ -260,9 +298,9 @@ class SevenBaseHandler(BaseApiHandler):
 
     def check_post(self, redis_key, expire=1):
         """
-         @description: 请求太频繁校验
-         @return: bool
-         @last_editors: HuangJianYi
+         :description: 请求太频繁校验
+         :return: bool
+         :last_editors: HuangJianYi
          """
         post_value = self.redis_init().get(redis_key)
         if post_value == None:
@@ -272,9 +310,9 @@ class SevenBaseHandler(BaseApiHandler):
 
     def check_lpush(self, queue_name, value, limitNum=100):
         """
-         @description: 入队列校验
-         @return: bool
-         @last_editors: HuangJianYi
+         :description: 入队列校验
+         :return: bool
+         :last_editors: HuangJianYi
          """
         list_len = self.redis_init().llen(queue_name)
         if int(list_len) >= int(limitNum):
@@ -284,22 +322,22 @@ class SevenBaseHandler(BaseApiHandler):
 
     def lpop(self, queue_name):
         """
-         @description: 出队列
-         @param queue_name：队列名称
-         @return: 
-         @last_editors: HuangJianYi
+         :description: 出队列
+         :param queue_name：队列名称
+         :return: 
+         :last_editors: HuangJianYi
          """
         result = self.redis_init().lpop(queue_name)
         return result
 
     def acquire_lock(self, lock_name, acquire_time=10, time_out=5):
         """
-        @description: 获取一个分布式锁
-        @param lock_name：锁定名称
-        @param acquire_time: 客户端等待获取锁的时间
-        @param time_out: 锁的超时时间
-        @return bool
-        @last_editors: HuangJianYi
+        :description: 获取一个分布式锁
+        :param lock_name：锁定名称
+        :param acquire_time: 客户端等待获取锁的时间
+        :param time_out: 锁的超时时间
+        :return bool
+        :last_editors: HuangJianYi
         """
         identifier = str(uuid.uuid4())
         end = time.time() + acquire_time
@@ -316,11 +354,11 @@ class SevenBaseHandler(BaseApiHandler):
 
     def release_lock(self, lock_name, identifier):
         """
-        @description: 释放一个锁
-        @param lock_name：锁定名称
-        @param identifier: identifier
-        @return bool
-        @last_editors: HuangJianYi
+        :description: 释放一个锁
+        :param lock_name：锁定名称
+        :param identifier: identifier
+        :return bool
+        :last_editors: HuangJianYi
         """
         lock = "lock:" + lock_name
         pip = self.redis_init().pipeline(True)
@@ -343,10 +381,10 @@ class SevenBaseHandler(BaseApiHandler):
 
     def random_weight(self, random_prize_dict_list):
         """
-        @description:  根据权重算法获取商品
-        @param random_prize_dict_list：权重列表
-        @return: str
-        @last_editors: HuangJianYi
+        :description:  根据权重算法获取商品
+        :param random_prize_dict_list：权重列表
+        :return: str
+        :last_editors: HuangJianYi
         """
         total = sum(random_prize_dict_list.values())  # 权重求和
         ra = random.uniform(0, total)  # 在0与权重和之前获取一个随机数
@@ -362,10 +400,10 @@ class SevenBaseHandler(BaseApiHandler):
 
     def get_status_name(self, status_id):
         """
-        @description: 获取状态
-        @param status_id：状态id
-        @return str
-        @last_editors: HuangJingCan
+        :description: 获取状态
+        :param status_id：状态id
+        :return str
+        :last_editors: HuangJingCan
         """
         if status_id == 0:
             return "未发货"
@@ -373,14 +411,16 @@ class SevenBaseHandler(BaseApiHandler):
             return "已发货"
         if status_id == 2:
             return "不予发货"
+        if status_id == 3:
+            return "订单同步失败"
 
     def get_date_list(self, start_date, end_date):
         """
-        @description: 两个日期之间的日期列表
-        @param start_date：开始日期
-        @param end_date：结束日期
-        @return: list
-        @last_editors: CaiYouBin
+        :description: 两个日期之间的日期列表
+        :param start_date：开始日期
+        :param end_date：结束日期
+        :return: list
+        :last_editors: CaiYouBin
         """
         if not start_date or not end_date:
             return []
@@ -397,21 +437,26 @@ class SevenBaseHandler(BaseApiHandler):
 
     def get_online_url(self, act_id, app_id):
         """
-        @description: 获取online_url
-        @param {act_id:活动id}
-        @param {app_id:app_id}
-        @return {str}
-        @last_editors: HuangJingCan
+        :description: 获取online_url
+        :param act_id:活动id
+        :param app_id:app_id
+        :param page:跳转的首页地址pages/index/index
+        :return str
+        :last_editors: HuangJingCan
         """
-        online_url = f"https://m.duanqu.com/?_ariver_appid={app_id}&page={CodingHelper.url_encode('pages/index/index')}&query=" + CodingHelper.url_encode(f"actid={act_id}")
+        page_index = ""
+        page = config.get_value("page_index")
+        if page:
+            page_index = "&page=" + CodingHelper.url_encode(page)
+        online_url = f"https://m.duanqu.com/?_ariver_appid={app_id}{page_index}&query=" + CodingHelper.url_encode(f"actid={act_id}")
         return online_url
 
     def get_live_url(self, app_id):
         """
-        @description: 获取live_url
-        @param {app_id:app_id}
-        @return {str}
-        @last_editors: HuangJingCan
+        :description: 获取live_url
+        :param app_id:app_id
+        :return str
+        :last_editors: HuangJingCan
         """
         live_url = f"https://market.m.taobao.com/app/taefed/shopping-delivery-wapp/index.html#/putin?mainKey=form&appId={app_id}"
         return live_url
\ No newline at end of file
