@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 """
-@Author: HuangJingCan
-@Date: 2020-08-12 09:06:24
-@LastEditTime: 2020-12-24 17:57:07
-@LastEditors: HuangJingCan
-@Description: 淘宝top接口基础类
+:Author: HuangJingCan
+:Date: 2020-08-12 09:06:24
+:LastEditTime: 2021-01-22 18:55:00
+:LastEditors: HuangJingCan
+:description: 淘宝top接口基础类
 """
 from seven_cloudapp.handlers.seven_base import *
 
@@ -19,15 +19,15 @@ from seven_cloudapp.models.db_models.app.app_info_model import *
 
 class TopBaseHandler(SevenBaseHandler):
     """
-    @description: 淘宝top接口基础类
+    :description: 淘宝top接口基础类
     """
     def get_sku_info(self, num_iids, access_token):
         """
-        @description: 获取sku信息
-        @param num_iids：num_iids
-        @param access_token：access_token
-        @return 
-        @last_editors: HuangJingCan
+        :description: 获取sku信息
+        :param num_iids：num_iids
+        :param access_token：access_token
+        :return 
+        :last_editors: HuangJingCan
         """
         try:
             resp = self.get_goods_list_for_goodsids(num_iids, access_token)
@@ -57,12 +57,12 @@ class TopBaseHandler(SevenBaseHandler):
 
     def get_sku_name(self, num_iids, sku_id, access_token):
         """
-        @description: 获取sku名称
-        @param num_iids：num_iids
-        @param sku_id：sku_id
-        @param access_token：access_token
-        @return 
-        @last_editors: HuangJingCan
+        :description: 获取sku名称
+        :param num_iids：num_iids
+        :param sku_id：sku_id
+        :param access_token：access_token
+        :return 
+        :last_editors: HuangJingCan
         """
         try:
             top.setDefaultAppInfo(config.get_value("app_key"), config.get_value("app_secret"))
@@ -92,17 +92,16 @@ class TopBaseHandler(SevenBaseHandler):
 
     def get_taobao_order(self, open_id, access_token, start_created="", end_created=""):
         """
-        @description: 获取淘宝订单
-        @param open_id：open_id
-        @param access_token：access_token
-        @param start_created：开始时间
-        @param end_created：结束时间
-        @return 
-        @last_editors: HuangJingCan
+        :description: 获取淘宝订单
+        :param open_id：open_id
+        :param access_token：access_token
+        :param start_created：开始时间
+        :param end_created：结束时间
+        :return 
+        :last_editors: HuangJingCan
         """
         all_order = []
         has_next = True
-
         try:
             top.setDefaultAppInfo(config.get_value("app_key"), config.get_value("app_secret"))
             req = top.api.OpenTradesSoldGetRequest()
@@ -124,7 +123,6 @@ class TopBaseHandler(SevenBaseHandler):
 
             while has_next:
                 resp = req.getResponse(access_token)
-
                 # self.logger_info.info(str(resp) + "【access_token】：" + self.get_taobao_param().access_token + "【获取订单】")
                 if "open_trades_sold_get_response" in resp.keys():
                     if "trades" in resp["open_trades_sold_get_response"].keys():
@@ -134,20 +132,15 @@ class TopBaseHandler(SevenBaseHandler):
 
             return all_order
         except Exception as ex:
-            if "submsg" in str(ex):
-                content_list = str(ex).split()
-                for content in content_list:
-                    if "submsg=该子帐号无此操作权限" in content:
-                        return self.reponse_json_error("NoPower", content[len("submsg="):])
-                    if "submsg=" in content:
-                        return self.reponse_json_error("Error", content[len("submsg="):])
+            self.logger_error.error(str(ex))
+            return []
 
     def rewards_status(self):
         """
-        @description: rewards_status
-        @param 
-        @return: 
-        @last_editors: CaiYouBin
+        :description: rewards_status
+        :param 
+        :return: 
+        :last_editors: CaiYouBin
         """
         status = [
             #等待卖家发货
@@ -165,10 +158,10 @@ class TopBaseHandler(SevenBaseHandler):
 
     def refund_status(self):
         """
-        @description: 给予奖励的子订单退款状态
-        @param 
-        @return: 
-        @last_editors: CaiYouBin
+        :description: 给予奖励的子订单退款状态
+        :param 
+        :return: 
+        :last_editors: CaiYouBin
         """
         status = [
             #没有退款
@@ -180,28 +173,42 @@ class TopBaseHandler(SevenBaseHandler):
         ]
         return status
 
-    def instantiate_new(self, description, icon):
+    def instantiate_new(self):
         """
-        @description: 实例化
-        @param description：活动简介
-        @param icon：活动图标
-        @return app_info
-        @last_editors: HuangJingCan
+        :description: 实例化
+        :param self:self
+        :return app_info
+        :last_editors: HuangJingCan
         """
-        app_name = config.get_value("project_name")
+        base_info = BaseInfoModel().get_entity()
+        if not base_info:
+            return self.reponse_json_error("BaseInfoError", "基础信息出错")
+        app_name = base_info.product_name
+        description = base_info.product_desc
+        icon = base_info.product_icon
         template_id = config.get_value("client_template_id")
-        template_version = ""
+        template_version = base_info.client_ver
         access_token = self.get_taobao_param().access_token
         user_nick = self.get_taobao_param().user_nick
-        if not user_nick:
-            return self.reponse_json_error("Error", "对不起,请先授权登录")
         open_id = self.get_taobao_param().open_id
-        store_user_nick = user_nick.split(':')[0]
-        if not store_user_nick:
-            return self.reponse_json_error("Error", "对不起，请先授权登录")
         app_info_model = AppInfoModel()
-        store_user_nick = user_nick.split(':')[0]
-        app_info = app_info_model.get_entity("store_user_nick=%s", params=store_user_nick)
+        app_info = None
+        app_id = self.get_param("app_id")
+        if app_id:
+            # 产品千牛后台GM工具（模拟登录）
+            app_info = app_info_model.get_entity("app_id=%s", params=app_id)
+            if app_info:
+                return self.reponse_json_success({"app_id": app_info.app_id, "store_user_nick": app_info.store_user_nick, "user_nick": app_info.store_user_nick, "access_token": app_info.access_token})
+            else:
+                return self.reponse_json_error("Error", "对不起，该店铺未实例化。")
+        else:
+            if not user_nick:
+                return self.reponse_json_error("Error", "对不起,请先授权登录")
+            store_user_nick = user_nick.split(':')[0]
+            if not store_user_nick:
+                return self.reponse_json_error("Error", "对不起，请先授权登录")
+            store_user_nick = user_nick.split(':')[0]
+            app_info = app_info_model.get_entity("store_user_nick=%s", params=store_user_nick)
         # 有效时间获取
         dead_date = self.get_dead_date(store_user_nick)
         if app_info:
@@ -219,8 +226,6 @@ class TopBaseHandler(SevenBaseHandler):
                 return self.reponse_json_success()
             if ":" in user_nick:
                 return self.reponse_json_error("Error", "对不起，初次创建活动包含实例化，请试用主账号进行创建。")
-            base_info = BaseInfoModel().get_entity()
-            template_version = base_info.client_ver
 
         try:
             top.setDefaultAppInfo(config.get_value("app_key"), config.get_value("app_secret"))
@@ -252,6 +257,7 @@ class TopBaseHandler(SevenBaseHandler):
             app_info.template_id = req.template_id
             app_info.template_ver = req.template_version
             app_info.access_token = access_token
+            app_info.expiration_date = dead_date
 
             if "shop_seller_get_response" in shop_info.keys():
                 app_info.store_name = shop_info["shop_seller_get_response"]["shop"]["title"]
@@ -290,14 +296,14 @@ class TopBaseHandler(SevenBaseHandler):
 
     def instantiate(self, user_nick, act_name, description, icon, name_ending):
         """
-        @description: 实例化
-        @param user_nick：用户昵称
-        @param act_name：活动名称
-        @param description：活动简介
-        @param icon：活动图标
-        @param name_ending：名称结尾
-        @return app_info
-        @last_editors: HuangJingCan
+        :description: 实例化
+        :param user_nick：用户昵称
+        :param act_name：活动名称
+        :param description：活动简介
+        :param icon：活动图标
+        :param name_ending：名称结尾
+        :return app_info
+        :last_editors: HuangJingCan
         """
         open_id = self.get_taobao_param().open_id
 
@@ -311,8 +317,9 @@ class TopBaseHandler(SevenBaseHandler):
             base_info = base_info_model.get_entity()
             template_id = config.get_value("client_template_id")
             template_version = base_info.client_ver
+            product_name = base_info.product_name
             access_token = self.get_taobao_param().access_token
-            app_info = self.instantiate_app(user_nick, open_id, description, icon, act_name, template_id, template_version, 1, access_token, name_ending)
+            app_info = self.instantiate_app(user_nick, open_id, description, icon, act_name, template_id, template_version, 1, access_token, name_ending, product_name)
 
             if isinstance(app_info, dict):
                 if "error" in app_info.keys():
@@ -322,21 +329,22 @@ class TopBaseHandler(SevenBaseHandler):
 
         return app_info
 
-    def instantiate_app(self, user_nick, open_id, description, icon, name, template_id, template_version, isfirst, access_token, name_ending):
+    def instantiate_app(self, user_nick, open_id, description, icon, name, template_id, template_version, isfirst, access_token, name_ending, product_name):
         """
-        @description: 实例化
-        @param user_nick：用户昵称
-        @param open_id：用户唯一标识
-        @param description：活动简介
-        @param icon：活动图标
-        @param name：活动名称
-        @param template_id：模板id
-        @param template_version：模板版本
-        @param isfirst：是否第一次
-        @param access_token：access_token
-        @param name_ending：name_ending
-        @return app_info
-        @last_editors: HuangJingCan
+        :description: 实例化
+        :param user_nick：用户昵称
+        :param open_id：用户唯一标识
+        :param description：活动简介
+        :param icon：活动图标
+        :param name：活动名称
+        :param template_id：模板id
+        :param template_version：模板版本
+        :param isfirst：是否第一次
+        :param access_token：access_token
+        :param name_ending：name_ending
+        :param product_name：项目名称
+        :return app_info
+        :last_editors: HuangJingCan
         """
         try:
             top.setDefaultAppInfo(config.get_value("app_key"), config.get_value("app_secret"))
@@ -354,7 +362,7 @@ class TopBaseHandler(SevenBaseHandler):
             req.ext_json = "{ \"name\":\"" + app_name + "\"}"
             req.icon = icon
             req.name = app_name
-            req.alias = config.get_value("project_name")
+            req.alias = product_name
             req.template_id = template_id
             req.template_version = template_version
             resp = req.getResponse(access_token)
@@ -403,26 +411,26 @@ class TopBaseHandler(SevenBaseHandler):
                     if "submsg=" in content:
                         if "名称已经存在" in content:
                             if isfirst == 1:
-                                return self.instantiate_app(user_nick, open_id, description, icon, name, template_id, template_version, 0, access_token, name_ending)
+                                return self.instantiate_app(user_nick, open_id, description, icon, name, template_id, template_version, 0, access_token, name_ending, product_name)
                             else:
                                 return {"error": "CreateError", "message": content[len("submsg="):]}
                         if "应用名称不合法" in content:
                             if isfirst == 1:
-                                return self.instantiate_app(user_nick, open_id, description, icon, name, template_id, template_version, 0, access_token, name_ending)
+                                return self.instantiate_app(user_nick, open_id, description, icon, name, template_id, template_version, 0, access_token, name_ending, product_name)
                             else:
                                 return {"error": "CreateError", "message": content[len("submsg="):]}
                         return {"error": "CreateError", "message": content[len("submsg="):]}
 
     def online_app(self, app_id, template_id, template_version, app_version, access_token):
         """
-        @description: app上线
-        @param app_id：app_id
-        @param template_id：模板id
-        @param template_version：模板版本
-        @param app_version：app版本
-        @param access_token：access_token
-        @return 
-        @last_editors: HuangJingCan
+        :description: app上线
+        :param app_id：app_id
+        :param template_id：模板id
+        :param template_version：模板版本
+        :param app_version：app版本
+        :param access_token：access_token
+        :return 
+        :last_editors: HuangJingCan
         """
         try:
             top.setDefaultAppInfo(config.get_value("app_key"), config.get_value("app_secret"))
@@ -446,10 +454,10 @@ class TopBaseHandler(SevenBaseHandler):
 
     def get_shop(self, access_token):
         """
-        @description: 获取店铺信息
-        @param access_token：access_token
-        @return: 
-        @last_editors: HuangJingCan
+        :description: 获取店铺信息
+        :param access_token：access_token
+        :return: 
+        :last_editors: HuangJingCan
         """
         try:
             top.setDefaultAppInfo(config.get_value("app_key"), config.get_value("app_secret"))
@@ -469,10 +477,10 @@ class TopBaseHandler(SevenBaseHandler):
 
     def get_user_seller(self, access_token):
         """
-        @description: 获取关注店铺用户信息
-        @param access_token：access_token
-        @return: 
-        @last_editors: HuangJingCan
+        :description: 获取关注店铺用户信息
+        :param access_token：access_token
+        :return: 
+        :last_editors: HuangJingCan
         """
         try:
             top.setDefaultAppInfo(config.get_value("app_key"), config.get_value("app_secret"))
@@ -492,10 +500,10 @@ class TopBaseHandler(SevenBaseHandler):
 
     def get_dead_date(self, user_nick):
         """
-        @description: 获取过期时间
-        @param user_nick：用户昵称
-        @return 
-        @last_editors: HuangJingCan
+        :description: 获取过期时间
+        :param user_nick：用户昵称
+        :return 
+        :last_editors: HuangJingCan
         """
         if self.get_is_test() == True:
             return config.get_value("test_dead_date")
@@ -516,10 +524,10 @@ class TopBaseHandler(SevenBaseHandler):
 
     def get_token(self):
         """
-        @description: 获取授权token
-        @param 
-        @return: 
-        @last_editors: CaiYouBin
+        :description: 获取授权token
+        :param 
+        :return: 
+        :last_editors: CaiYouBin
         """
         if self.get_is_test() == True:
             return ""
@@ -538,15 +546,15 @@ class TopBaseHandler(SevenBaseHandler):
 
     def get_goods_list(self, page_index, page_size, goods_name, order_tag, order_by, access_token):
         """
-        @description: 导入商品列表（获取当前会话用户出售中的商品列表）
-        @param page_index：页索引
-        @param page_size：页大小
-        @param goods_name：商品名称
-        @param order_tag：order_tag
-        @param order_by：排序类型
-        @param access_token：access_token
-        @return 
-        @last_editors: HuangJingCan
+        :description: 导入商品列表（获取当前会话用户出售中的商品列表）
+        :param page_index：页索引
+        :param page_size：页大小
+        :param goods_name：商品名称
+        :param order_tag：order_tag
+        :param order_by：排序类型
+        :param access_token：access_token
+        :return 
+        :last_editors: HuangJingCan
         """
         try:
             top.setDefaultAppInfo(config.get_value("app_key"), config.get_value("app_secret"))
@@ -577,12 +585,12 @@ class TopBaseHandler(SevenBaseHandler):
 
     def get_goods_list_client(self, page_index, page_size, access_token):
         """
-        @description: 导入商品列表（客户端）
-        @param page_index：页索引
-        @param page_size：页大小
-        @param access_token：access_token
-        @return 
-        @last_editors: HuangJingCan
+        :description: 导入商品列表（客户端）
+        :param page_index：页索引
+        :param page_size：页大小
+        :param access_token：access_token
+        :return 
+        :last_editors: HuangJingCan
         """
         try:
             top.setDefaultAppInfo(config.get_value("app_key"), config.get_value("app_secret"))
@@ -624,11 +632,11 @@ class TopBaseHandler(SevenBaseHandler):
 
     def get_goods_info(self, num_iid, access_token):
         """
-        @description: 导入商品列表
-        @param num_iids：num_iids
-        @param access_token：access_token
-        @return 
-        @last_editors: HuangJingCan
+        :description: 导入商品列表
+        :param num_iids：num_iids
+        :param access_token：access_token
+        :return 
+        :last_editors: HuangJingCan
         """
         try:
             top.setDefaultAppInfo(config.get_value("app_key"), config.get_value("app_secret"))
@@ -652,10 +660,10 @@ class TopBaseHandler(SevenBaseHandler):
 
     def app_update(self):
         """
-        @description: app更新
-        @param 
-        @return 
-        @last_editors: HuangJingCan
+        :description: app更新
+        :param 
+        :return 
+        :last_editors: HuangJingCan
         """
         app_id = self.get_param("app_id")
         client_template_id = config.get_value("client_template_id")
@@ -712,12 +720,12 @@ class TopBaseHandler(SevenBaseHandler):
 
     def change_throw_goods_list_status(self, throw_goods_ids, url, status):
         """
-        @description: change_throw_goods_list_status
-        @param throw_goods_ids：throw_goods_ids
-        @param url：链接地址
-        @param status：状态
-        @return 
-        @last_editors: HuangJingCan
+        :description: change_throw_goods_list_status
+        :param throw_goods_ids：throw_goods_ids
+        :param url：链接地址
+        :param status：状态
+        :return 
+        :last_editors: HuangJingCan
         """
         try:
             top.setDefaultAppInfo(config.get_value("app_key"), config.get_value("app_secret"))
@@ -734,17 +742,17 @@ class TopBaseHandler(SevenBaseHandler):
                 content_list = str(ex).split()
                 for content in content_list:
                     if "submsg=该子帐号无此操作权限" in content:
-                        return self.reponse_json_error("NoPower", content[len("submsg="):])
+                        return self.return_dict_error("NoPower", content[len("submsg="):])
                     if "submsg=" in content:
-                        return self.reponse_json_error("Error", content[len("submsg="):])
+                        return self.return_dict_error("Error", content[len("submsg="):])
 
     def get_goods_list_for_goodsids(self, num_iids, access_token):
         """
-        @description: 批量获取商品详细信息
-        @param num_iids：商品id列表
-        @param access_token：access_token
-        @return list
-        @last_editors: HuangJingCan
+        :description: 批量获取商品详细信息
+        :param num_iids：商品id列表
+        :param access_token：access_token
+        :return list
+        :last_editors: HuangJingCan
         """
         try:
             top.setDefaultAppInfo(config.get_value("app_key"), config.get_value("app_secret"))
@@ -759,17 +767,17 @@ class TopBaseHandler(SevenBaseHandler):
                 content_list = str(ex).split()
                 for content in content_list:
                     if "submsg=该子帐号无此操作权限" in content:
-                        return {"error_code": "NoPower", "error_message": content[len("submsg="):]}
+                        return self.return_dict_error("NoPower", content[len("submsg="):])
                     if "submsg=" in content:
-                        return {"error_code": "Error", "error_message": content[len("submsg="):]}
+                        return self.return_dict_error("Error", content[len("submsg="):])
 
     def get_taobao_order_info(self, order_no, access_token):
         """
-        @description: 获取单笔订单
-        @param order_no：订单编号
-        @param access_token：access_token
-        @return: 
-        @last_editors: CaiYouBin
+        :description: 获取单笔订单
+        :param order_no：订单编号
+        :param access_token：access_token
+        :return: 
+        :last_editors: CaiYouBin
         """
         try:
             top.setDefaultAppInfo(config.get_value("app_key"), config.get_value("app_secret"))
@@ -789,16 +797,16 @@ class TopBaseHandler(SevenBaseHandler):
                 content_list = str(ex).split()
                 for content in content_list:
                     if "submsg=该子帐号无此操作权限" in content:
-                        return self.reponse_json_error("NoPower", content[len("submsg="):])
+                        return self.return_dict_error("NoPower", content[len("submsg="):])
                     if "submsg=" in content:
-                        return self.reponse_json_error("Error", content[len("submsg="):])
+                        return self.return_dict_error("Error", content[len("submsg="):])
 
     def get_coupon_details(self, right_ename):
         """
-        @description: 获取优惠券详情信息(请求top接口)
-        @param right_ename:奖池ID
-        @return: dict
-        @last_editors: LaiKaiXiang
+        :description: 获取优惠券详情信息(请求top接口)
+        :param right_ename:奖池ID
+        :return: dict
+        :last_editors: LaiKaiXiang
         """
         right_ename = self.get_param("right_ename")
         access_token = self.get_taobao_param().access_token
@@ -810,7 +818,8 @@ class TopBaseHandler(SevenBaseHandler):
             req.app_name = "promotioncenter-" + config.get_value("server_template_id")
             req.award_type = "1"
             resp = req.getResponse(access_token)
-            return resp
+
+            return self.reponse_json_success(resp)
         except Exception as ex:
             # self.logger_error.error(str(ex) + "【获取优惠券详情信息】")
             if "submsg" in str(ex):
@@ -819,4 +828,94 @@ class TopBaseHandler(SevenBaseHandler):
                     if "submsg=该子帐号无此操作权限" in content:
                         return self.reponse_json_error("NoPower", content[len("submsg="):])
                     if "submsg=" in content:
-                        return self.reponse_json_error("Error", content[len("submsg="):])
\ No newline at end of file
+                        return self.reponse_json_error("Error", content[len("submsg="):])
+
+    def get_member_info(self, access_token):
+        """
+        :description: 获取top接口淘宝会员信息
+        :param access_token:access_token
+        :return:resp
+        :last_editors: HuangJianYi
+        """
+        try:
+            top.setDefaultAppInfo(config.get_value("app_key"), config.get_value("app_secret"))
+            req = top.api.CrmMemberIdentityGetRequest()
+            req.mix_nick = self.get_taobao_param().mix_nick
+            resp = req.getResponse(access_token)
+            return resp
+        except Exception as ex:
+            self.logger_error.error(str(ex) + "【获取会员信息top接口】")
+            return {}
+
+    def check_is_member(self, access_token):
+        """
+        :description: 获取top接口淘宝会员信息
+        :param access_token:access_token
+        :return:bool
+        :last_editors: HuangJianYi
+        """
+        is_member = False
+        resp = self.get_member_info(access_token)
+        if "crm_member_identity_get_response" in resp.keys():
+            if "result" in resp["crm_member_identity_get_response"].keys():
+                if "member_info" in resp["crm_member_identity_get_response"]["result"].keys():
+                    is_member = True
+        return is_member
+
+    def get_user_group_list(self, access_token):
+        """
+        :description: 获取top接口用户加入的群聊列表
+        :param access_token:access_token
+        :return:dict
+        :last_editors: HuangJianYi
+        """
+        try:
+            top.setDefaultAppInfo(config.get_value("app_key"), config.get_value("app_secret"))
+            req = top.api.ChattingPlatformUserGroupListRequest()
+            req.user_nick = self.get_taobao_param().user_nick
+            resp = req.getResponse(access_token)
+            return resp
+        except Exception as ex:
+            # self.logger_error.error(str(ex) + "【获取用户加入的群聊列表top接口】")
+            return {}
+
+    def check_join_group(self, access_token):
+        """
+        :description: 请求top接口判断是否加入群聊
+        :param access_token:access_token
+        :return:bool
+        :last_editors: HuangJianYi
+        """
+        is_join_group = False
+        resp = self.get_user_group_list(access_token)
+        if "chatting_platform_user_group_list_response" in resp.keys():
+            if "result" in resp["chatting_platform_user_group_list_response"].keys():
+                if "group_list" in resp["chatting_platform_user_group_list_response"]["result"].keys():
+                    if "open_group_info_dto" in resp["chatting_platform_user_group_list_response"]["result"]["group_list"].keys():
+                        if len(resp["chatting_platform_user_group_list_response"]["result"]["group_list"]["open_group_info_dto"]) > 0:
+                            is_join_group = True
+        return is_join_group
+
+    def get_join_member_url(self, access_token):
+        """
+        :description: 请求top接口获取加入会员地址
+        :param access_token:access_token
+        :return:str
+        :last_editors: HuangJianYi
+        """
+        join_member_url = ""
+        try:
+            top.setDefaultAppInfo(config.get_value("app_key"), config.get_value("app_secret"))
+            req = top.api.CrmMemberJoinurlGetRequest()
+            req.callback_url = ""
+            req.extra_info = "{\"source\":\"isvapp\",\"activityId\":\"\",\"entrance\":\"hudong\"}"
+            resp = req.getResponse(access_token)
+            if "crm_member_joinurl_get_response" in resp.keys():
+                if "result" in resp["crm_member_joinurl_get_response"].keys():
+                    if "result" in resp["crm_member_joinurl_get_response"]["result"].keys():
+                        join_member_url = resp["crm_member_joinurl_get_response"]["result"]["result"]
+        except Exception as ex:
+            # self.logger_error.error(str(ex) + "【获取加入会员地址top接口】")
+            return ""
+
+        return join_member_url
\ No newline at end of file
