@@ -28,6 +28,7 @@ class BaseInfo:
         self.client_ver = ""  # 客户端版本号
         self.server_ver = ""  # 服务端版本号
         self.update_function = ""  # 版本更新内容
+        self.update_function_b = ""  # 千牛端版本更新内容
         self.store_study_url = ""  # 店铺装修教程图文地址（如何上架小程序）
         self.study_url = ""  # 后台配置图文教程
         self.video_url = ""  # 后台配置视频教程
@@ -39,13 +40,13 @@ class BaseInfo:
         self.course_strategy = ""  # 教程或者攻略
         self.menu_config = ""  # 菜单配置信息
         self.is_remind_phone = 0  # 是否提醒提示配置手机号
-        self.is_force_update = 0  # 是个强制更新客户端版本
+        self.is_force_update = 0  # 是否强制更新客户端版本
         self.create_date = "1900-01-01 00:00:00"  # 创建时间
         self.modify_date = "1900-01-01 00:00:00"  # 修改时间
 
     @classmethod
     def get_field_list(self):
-        return ['id', 'guid', 'product_name', 'product_icon', 'product_desc', 'service_market_url', 'customer_service', 'experience_img', 'client_ver', 'server_ver', 'update_function', 'store_study_url', 'study_url', 'video_url', 'course_url', 'price_gare', 'product_price', 'decoration_poster', 'friend_link', 'course_strategy', 'menu_config', 'is_remind_phone', 'is_force_update', 'create_date', 'modify_date']
+        return ['id', 'guid', 'product_name', 'product_icon', 'product_desc', 'service_market_url', 'customer_service', 'experience_img', 'client_ver', 'server_ver', 'update_function', 'update_function_b', 'store_study_url', 'study_url', 'video_url', 'course_url', 'price_gare', 'product_price', 'decoration_poster', 'friend_link', 'course_strategy', 'menu_config', 'is_remind_phone', 'is_force_update', 'create_date', 'modify_date']
         
     @classmethod
     def get_primary_key(self):
