@@ -23,11 +23,13 @@ class BehaviorLog:
         self.open_id = ""  # open_id
         self.orm_id = 0  # 统计映射表id
         self.inc_value = 0  # 增加的值
+        self.create_day = 0  # 创建日
+        self.create_month = 0  # 创建月
         self.create_date = "1900-01-01 00:00:00"  # 创建时间
 
     @classmethod
     def get_field_list(self):
-        return ['id', 'app_id', 'act_id', 'open_id', 'orm_id', 'inc_value', 'create_date']
+        return ['id', 'app_id', 'act_id', 'open_id', 'orm_id', 'inc_value', 'create_day', 'create_month', 'create_date']
         
     @classmethod
     def get_primary_key(self):
