@@ -22,12 +22,15 @@ class MarketingProgram:
         self.link_title = ""  # 链接标题
         self.link_url = ""  # 链接地址
         self.content = ""  # 内容说明
+        self.sort_index = 0  # 排序
+        self.is_release = 0  # 是否发布（1是0否）
+        self.release_date = "1900-01-01 00:00:00"  # 发布时间
         self.create_date = "1900-01-01 00:00:00"  # 创建时间
         self.modify_date = "1900-01-01 00:00:00"  # 更新时间
 
     @classmethod
     def get_field_list(self):
-        return ['id', 'group_name', 'link_title', 'link_url', 'content', 'create_date', 'modify_date']
+        return ['id', 'group_name', 'link_title', 'link_url', 'content', 'sort_index', 'is_release', 'release_date', 'create_date', 'modify_date']
         
     @classmethod
     def get_primary_key(self):
