@@ -23,12 +23,13 @@ class ProductPrice:
         self.end_time = "1900-01-01 00:00:00"  # 结束时间
         self.content = ""  # 内容
         self.is_release = 0  # 是否发布（1是0否）
+        self.release_date = "1900-01-01 00:00:00"  # 发布时间
         self.create_time = "1900-01-01 00:00:00"  # 创建时间
-        self.update_time = "1900-01-01 00:00:00"  # 更新时间
+        self.modify_date = "1900-01-01 00:00:00"  # 更新时间
 
     @classmethod
     def get_field_list(self):
-        return ['id', 'plan_name', 'begin_time', 'end_time', 'content', 'is_release', 'create_time', 'update_time']
+        return ['id', 'plan_name', 'begin_time', 'end_time', 'content', 'is_release', 'release_date', 'create_time', 'modify_date']
         
     @classmethod
     def get_primary_key(self):
