@@ -1,19 +1,19 @@
 # -*- coding: utf-8 -*-
 """
-@Author: HuangJingCan
-@Date: 2020-05-02 15:17:41
-@LastEditTime: 2020-12-16 09:16:26
-@LastEditors: HuangJingCan
-@Description: 自定义实体
+:Author: HuangJingCan
+:Date: 2020-05-02 15:17:41
+:LastEditTime: 2020-12-16 09:16:26
+:LastEditors: HuangJingCan
+:description: 自定义实体
 """
 
 
 class InvokeResult():
     """
-    @description: 接口返回实体
-    @param {type} 
-    @return: InvokeResult
-    @last_editors: HuangJingCan
+    :description: 接口返回实体
+    :param {type} 
+    :return: InvokeResult
+    :last_editors: HuangJingCan
     """
     def __init__(self):
         self.success = True
@@ -22,10 +22,10 @@ class InvokeResult():
 
 class InvokeResultData():
     """
-    @description: 接口返回实体
-    @param {type} 
-    @return: 
-    @last_editors: HuangJingCan
+    :description: 接口返回实体
+    :param {type} 
+    :return: 
+    :last_editors: HuangJingCan
     """
     def __init__(self):
         self.success = True
@@ -36,10 +36,10 @@ class InvokeResultData():
 
 class FileUploadInfo():
     """
-    @description: 文件上传信息实体
-    @param {type} 
-    @return: FileUploadInfo
-    @last_editors: HuangJingCan
+    :description: 文件上传信息实体
+    :param {type} 
+    :return: FileUploadInfo
+    :last_editors: HuangJingCan
     """
     def __init__(self):
         # 检查值
@@ -58,23 +58,23 @@ class FileUploadInfo():
 
 class PageInfo():
     """
-    @description: 分页列表实体
-    @param page_index：当前索引号
-    @param page_size：页大小
-    @param record_count：总记录数
-    @param data：数据
-    @return: PageInfo
-    @last_editors: HuangJingCan
+    :description: 分页列表实体
+    :param page_index：当前索引号
+    :param page_size：页大小
+    :param record_count：总记录数
+    :param data：数据
+    :return: PageInfo
+    :last_editors: HuangJingCan
     """
     def __init__(self, page_index=0, page_size=10, record_count=0, data=None):
         """
-        @description: 分页列表实体
-        @param page_index：当前索引号
-        @param page_size：页大小
-        @param record_count：总记录数
-        @param data：数据
-        @return: PageInfo
-        @last_editors: HuangJingCan
+        :description: 分页列表实体
+        :param page_index：当前索引号
+        :param page_size：页大小
+        :param record_count：总记录数
+        :param data：数据
+        :return: PageInfo
+        :last_editors: HuangJingCan
         """
         # 数据
         self.data = data
